@@ -36,6 +36,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.Statement;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -241,6 +242,32 @@ public class DorisSystem implements Serializable {
         return sb.toString();
     }
 
+    public Map<String, String> getTableFieldNames(String databaseName, String tableName) {
+        if (!databaseExists(databaseName)) {
+            throw new DorisRuntimeException("database" + databaseName + " is not exists");
+        }
+        String sql =
+                String.format(
+                        "SELECT COLUMN_NAME,DATA_TYPE "
+                                + "FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA`= '%s' AND `TABLE_NAME`= '%s'",
+                        databaseName, tableName);
+
+        Map<String, String> columnValues = new HashMap<>();
+        try (PreparedStatement ps =
+                jdbcConnectionProvider.getOrEstablishConnection().prepareStatement(sql)) {
+            ResultSet rs = ps.executeQuery();
+            while (rs.next()) {
+                String filedName = rs.getString(1);
+                String datatype = rs.getString(2);
+                columnValues.put(filedName, datatype);
+            }
+            return columnValues;
+        } catch (Exception e) {
+            throw new DorisSystemException(
+                    String.format("The following SQL query could not be executed: %s", sql), e);
+        }
+    }
+
     private static void buildColumn(StringBuilder sql, FieldSchema field, boolean isKey) {
         String fieldType = field.getTypeString();
         if (isKey && DorisType.STRING.equals(fieldType)) {
